By default, the new object will own the data files.
Examples
mod <- house_ds()
out <- mrgsim_ds(mod)
out2 <- copy_ds(out)
check_ownership(out)
#> [1] FALSE
check_ownership(out2)
#> [1] TRUE
By default, the new object will own the data files.
mod <- house_ds()
out <- mrgsim_ds(mod)
out2 <- copy_ds(out)
check_ownership(out)
#> [1] FALSE
check_ownership(out2)
#> [1] TRUE