Thin wrappers around mrgsolve model-loading functions (mread(),
mcode(), modlib(), house(), mread_cache()) that additionally call
save_process_info() to stamp the model with the current process ID. This
stamp is required by mrgsim_ds() to correctly associate simulation outputs
with the process that created them.
Value
A model object with process information saved, suitable for use with
mrgsim_ds().
Examples
mod <- house_ds()
mod
#>
#>
#> -------------- source: housemodel.cpp --------------
#>
#> project: /home/runner/wor...solve/project
#> shared object: mrgsolve
#>
#> time: start: 0 end: 120 delta: 0.25
#> add: <none>
#> compartments: GUT CENT RESP [3]
#> parameters: CL VC KA F1 D1 WTCL WTVC SEXCL SEXVC
#> KIN KOUT IC50 WT SEX [14]
#> captures: DV CP [2]
#> omega: 4x4
#> sigma: 1x1
#>
#> solver: rtol: 1e-08 atol: 1e-08 itol: 1 (scalar)
#> ------------------------------------------------------