Skip to contents

Save information about the R process that loaded a model

Usage

save_process_info(x)

Arguments

x

a model object.

Value

An updated model object suitable for using with mrgsim_ds().

Examples

mod <- mrgsolve::house()

mod <- save_process_info(mod)