Save information about the R process that loaded a model
Value
An updated model object suitable for using with mrgsim_ds().
Examples
mod <- mrgsolve::house()
mod <- save_process_info(mod)
Save information about the R process that loaded a model
An updated model object suitable for using with mrgsim_ds().
mod <- mrgsolve::house()
mod <- save_process_info(mod)