Stamps the model object with the current process ID and tempdir() path so
that mrgsim_ds() knows where to write output files. This is called
automatically by mread_ds(), house_ds(), and the other model-loading
wrappers. Call it directly only when you load a model through the base
mrgsolve functions (e.g. mrgsolve::mread()) and still want to use
mrgsim_ds().
Value
An updated model object suitable for using with mrgsim_ds().
Examples
mod <- mrgsolve::house()
mod <- save_process_info(mod)